/*
 PureMVC standard Javascript port by Frederic Saunier <frederic.saunier@puremvc.org>
 PureMVC - Copyright(c) 2006-2011 Futurescale, Inc., Some rights reserved.
 Your reuse is governed by the Creative Commons Attribution 3.0 License
*/

/**
 * @classDescription
 * A base <code>Command</code> implementation.
 * 
 * <P>
 * Your subclass should override the <code>execute</code> method where
 * your business logic will handle the <code>Notification</code>.
 *
 * @extends org.puremvc.js.standard.patterns.observer.Notifier Notifier
 *
 * @constructor
 */
function SimpleCommand(){}

/**
 * @extends org.puremvc.js.standard.patterns.observer.Notifier Notifier
 */
SimpleCommand.prototype = new Notifier();

/**
 * @override
 *
 * Initialize a <code>SimpleCommand</code> instance.
 * 
 * @return {SimpleCommand}
 * 		This <code>SimpleCommand</code> instance.
 */
SimpleCommand.prototype.initialize = function()
{
	Notifier.prototype.initialize.call(this);

	return this;
}

/**
 * Fulfill the use-case initiated by the given <code>Notification</code>.
 *
 * <P>
 * In the Command Pattern, an application use-case typically begins with
 * some user action, which results in a <code>Notification</code> being
 * broadcast, which is handled by business logic in the
 * <code>execute</code> method of an <code>ICommand</code>.
 *
 * @param {Notification} notification 
 * 		The <code>Notification</code> to handle.
 */
SimpleCommand.prototype.execute = function( notification ){}