/*
 PureMVC standard Javascript port by Frederic Saunier <frederic.saunier@puremvc.org>
 PureMVC - Copyright(c) 2006-2011 Futurescale, Inc., Some rights reserved.
 Your reuse is governed by the Creative Commons Attribution 3.0 License
*/

/**
 * @classDescription
 * The Base <code>Notifier</code> implementation.
 *
 * <P>
 * <code>MacroCommand</code>, <code>Command</code>,
 * <code>Mediator</code> and <code>Proxy</code> all have a need to send
 * <code>Notifications</code>.
 * 
 * <P>
 * The <code>Notifier</code> base class provides a common method
 * called <code>sendNotification</code> that relieves implementation
 * code of the necessity to actually construct
 * <code>Notification</code>s.
 *
 * <P>
 * The <code>Notifier</code> class, which all of the above mentioned
 * classes extend, provides an initialized reference to the
 * <code>Facade</code> singleton, which is required by the convenience
 * method <code>sendNotification</code>	for sending
 * <code>Notifications</code>, but it also eases implementation as
 * these classes have frequent <code>Facade</code> interactions and
 * uusually require access to the facade anyway.
 * 
 * @see org.puremvc.js.standard.patterns.facade.Facade Facade
 * 
 * @constructor
 */
function Notifier(){}

/**
 * Initialize a <code>Notifier</code> instance.
 * 
 * @return {Notifier}
 * 		This <code>Notifier</code> instance.
 */
Notifier.prototype.initialize = function()
{
	this.facade = Facade.getInstance();
	
	return this;
}

/**
 * Facade of the <code>Notifier</code> object.
 * 
 * @private
 */
Notifier.prototype.facade = null;
	
/**
 * Create and send a <code>Notification</code>.
 *
 * <P>
 * Keeps us from having to construct new Notification
 * instances in our implementation code.
 * 
 * @param {String} notificationName
 * 		The name of the notification to send.
 * 
 * @param {Object} body
 * 		The (optional) body of the notification.
 *
 * @param {String} type
 * 		The (optional) type of the notification.
 */
Notifier.prototype.sendNotification = function( notificationName/*String*/, body/*Object */, type/*String*/ )
{
	this.facade.sendNotification( notificationName, body, type );
}