/*
 PureMVC standard Javascript port by Frederic Saunier Saunier <frederic.saunier@puremvc.org>
 PureMVC - Copyright(c) 2006-2011 Futurescale, Inc., Some rights reserved.
 Your reuse is governed by the Creative Commons Attribution 3.0 License
*/

/**
 * @classDescription
 * A Mediator class used by ViewTest.
 * 
 * @see org.puremvc.js.standard.core.view.ViewTest ViewTest
 * 
 * @constructor
 */
function ViewTestMediator(){}

/**
 * @extends  org.puremvc.js.standard.patterns.mediator.Mediator Mediator
 */
ViewTestMediator.prototype = new Mediator();

/**
 * @override
 * 
 * Initialize a <code>ViewTestMediator</code> instance.
 * 
 * @param {Object} view
 * 		The view component handled by this <code>Mediator</code>.
 * 
 * @return {ViewTestMediator}
 * 		This <code>ViewTestMediator</code> instance.
 */
ViewTestMediator.prototype.initialize = function( view )
{
	Mediator.prototype.initialize.call( this, ViewTestMediator.NAME, view );
	
	return this;
}

/**
 * @override
 *
 * @return {Array}
 * 		The list of notifications names in which is interested the
 * 		<code>Mediator</code>.
 */
ViewTestMediator.prototype.listNotificationInterests = function()
{
	// be sure that the mediator has some Observers created
	// in order to test removeMediator
	return [ 'ABC', 'DEF', 'GHI'  ];
}

/**
 * The Mediator name.
 * 
 * @type {String}
 * @private
 */
ViewTestMediator.NAME = "ViewTestMediator";
