/*
 PureMVC standard Javascript port by Frederic Saunier Saunier <frederic.saunier@puremvc.org>
 PureMVC - Copyright(c) 2006-2011 Futurescale, Inc., Some rights reserved.
 Your reuse is governed by the Creative Commons Attribution 3.0 License
*/

/**
 * A Mediator class used by ViewTest.
 * 
 * @see org.puremvc.js.standard.core.view.ViewTest ViewTest
 * @extends org.puremvc.js.standard.patterns.mediator.Mediator Mediator
 * 
 * @constructor
 */
function ViewTestMediator3(){}

/**
 * @extends  org.puremvc.js.standard.patterns.mediator.Mediator Mediator
 */
ViewTestMediator3.prototype = new Mediator();

/**
 * @override
 * 
 * Initialize a <code>ViewTestMediator3</code> instance.
 * 
 * @param {Object} view
 * 		The view component handled by this <code>Mediator</code>.
 * 
 * @return {ViewTestMediator3}
 * 		This <code>ViewTestMediator3</code> instance.
 */
ViewTestMediator3.prototype.initialize = function( view )
{
	Mediator.prototype.initialize.call( this, ViewTestMediator3.NAME, view );
	
	return this;
}

/**
 * @classDescription
 * Standard getter to return the view handled by the
 * <code>Mediator</code>.
 * 
 * @return {Object}
 * 		The view handled by the <code>Mediator</code>.
 * 
 * @private
 */
ViewTestMediator3.prototype.getViewTest = function()
{
	return this.viewComponent;
}

/**
 * @override
 *
 * @return {Array}
 * 		The list of notifications names in which is interested the
 * 		<code>Mediator</code>.
 */
ViewTestMediator3.prototype.listNotificationInterests = function()
{
	// be sure that the mediator has some Observers created
	// in order to test removeMediator
	return [ ViewTest.NOTE3 ];
}

/**
 * @override
 *
 * @param {Notification} notification
 * 		The notification instance to be handled.
 */
ViewTestMediator3.prototype.handleNotification = function( notification )
{
	this.getViewTest().lastNotification = notification.getName();
}


/**
 * The Mediator name.
 * 
 * @type {String}
 * @private
 */
ViewTestMediator3.NAME = 'ViewTestMediator3';