/*
 PureMVC standard Javascript port by Frederic Saunier Saunier <frederic.saunier@puremvc.org>
 PureMVC - Copyright(c) 2006-2011 Futurescale, Inc., Some rights reserved.
 Your reuse is governed by the Creative Commons Attribution 3.0 License
*/

/**
 * @classDescription
 * A Mediator class used by ViewTest.
 * 
 * @see org.puremvc.js.standard.core.view.ViewTest ViewTest
 * @extends org.puremvc.js.standard.patterns.mediator.Mediator Mediator
 *
 * @constructor
 */
function ViewTestMediator4(){}

/**
 * @extends  org.puremvc.js.standard.patterns.mediator.Mediator Mediator
 */
ViewTestMediator4.prototype = new Mediator();

/**
 * @override
 * 
 * Initialize a <code>ViewTestMediator4</code> instance.
 * 
 * @param {Object} view
 * 		The view component handled by this <code>Mediator</code>.
 * 
 * @return {ViewTestMediator4}
 * 		This <code>ViewTestMediator4</code> instance.
 */
ViewTestMediator4.prototype.initialize = function( view )
{
	Mediator.prototype.initialize.call( this, ViewTestMediator4.NAME, view );
	
	return this;
}

/**
 * Standard getter to return the view handled by the
 * <code>Mediator</code>.
 * 
 * @return {Object}
 * 		The view handled by the <code>Mediator</code>.
 * 
 * @private
 */
ViewTestMediator4.prototype.getViewTest = function()
{
	return this.viewComponent;
}
	
/**
 * @override
 */	
ViewTestMediator4.prototype.onRegister = function()
{
	this.getViewTest().onRegisterCalled = true;
}
		
	
/**
 * @override
 */	
ViewTestMediator4.prototype.onRemove = function()
{
	this.getViewTest().onRemoveCalled = true;
}

/**
 * The Mediator name.
 * 
 * @type {String}
 * @private
 */
ViewTestMediator4.NAME = 'ViewTestMediator4';