/*
 PureMVC standard Javascript port by Frederic Saunier Saunier <frederic.saunier@puremvc.org>
 PureMVC - Copyright(c) 2006-2011 Futurescale, Inc., Some rights reserved.
 Your reuse is governed by the Creative Commons Attribution 3.0 License
*/

/**
 * @classDescription
 * A Mediator class used by ViewTest.
 * 
 * @see org.puremvc.js.standard.core.view.ViewTest ViewTest
 * @extends org.puremvc.js.standard.patterns.mediator.Mediator Mediator
 * 
 * @constructor
 */
function ViewTestMediator6(){}

/**
 * @extends  org.puremvc.js.standard.patterns.mediator.Mediator Mediator
 */
ViewTestMediator6.prototype = new Mediator();

/**
 * @override
 * 
 * Initialize a <code>ViewTestMediator6</code> instance.
 *
 * @param {String} name
 * 		The name of the <code>Mediator</code>.
 * 
 * @param {Object} view
 * 		The view component handled by this <code>Mediator</code>.
 * 
 * @return {ViewTestMediator6}
 * 		This <code>ViewTestMediator6</code> instance.
 */
ViewTestMediator6.prototype.initialize = function( name, view )
{
	Mediator.prototype.initialize.call( this, name, view );

	return this;
}
		
/**
 * Standard getter to return the view handled by the
 * <code>Mediator</code>.
 * 
 * @return {Object}
 * 		The view handled by the <code>Mediator</code>.
 * 
 * @private
 */
ViewTestMediator6.prototype.getViewTest = function()
{
	return this.viewComponent;
}

/**
 * @override
 *
 * @return {Array}
 * 		The list of notifications names in which is interested the
 * 		<code>Mediator</code>.
 */
ViewTestMediator6.prototype.listNotificationInterests = function()
{
	return [ ViewTest.NOTE6 ];
}

/**
 * @override
 *
 * @param {Notification} notification
 * 		The notification instance to be handled.
 */
ViewTestMediator6.prototype.handleNotification = function( notification )
{
	this.facade.removeMediator(this.getMediatorName());
}

/**
 * @override
 */
ViewTestMediator6.prototype.onRemove= function()
{
	this.getViewTest().counter++;
}

/**
 * The Mediator name.
 * 
 * @type {String}
 * @private
 */
ViewTestMediator6.NAME = 'ViewTestMediator6';