/*
 PureMVC standard Javascript port by Frederic Saunier Saunier <frederic.saunier@puremvc.org>
 PureMVC - Copyright(c) 2006-2011 Futurescale, Inc., Some rights reserved.
 Your reuse is governed by the Creative Commons Attribution 3.0 License
*/

/**
 * @classDescription
 * A Notification class used by ViewTest.
 *
 * @see org.puremvc.js.standard.core.view.ViewTest ViewTest
 * @extends org.puremvc.js.standard.observer.Notification Notification
 * 
 * @constructor
 */
function ViewTestNote(){}

/**
 * @extends org.puremvc.js.standard.observer.Notification Notification
 */
ViewTestNote.prototype = new Notification();

/**
 * Initialize a <code>ViewTestMediator</code> instance.
 * 
 * @param {String} name
 * 		Ignored and forced to NAME.
 * 
 * @param {String} body 
 * 		The body of the Notification to be initialized.
 * 
 * @return {ViewTestNote}
 * 		This <code>ViewTestNote</code> instance.
 */
ViewTestNote.prototype.initialize = function( name/*String*/, body/*Object*/ )
{
	Notification.prototype.initialize.call( this, ViewTestNote.NAME, body );
	
	return this;
}

/**
 * The name of this Notification.
 * @type {String}
 */
ViewTestNote.NAME = "ViewTestNote";

/**
 * Factory method.
 * 
 * <P> 
 * This method creates new instances of the ViewTestNote class,
 * automatically setting the note name so you don't have to. Use
 * this as an alternative to the constructor.</P>
 * 
 * @param {Object} body
 * 		The body of the Notification to be constructed.
 *
 * @return {Notification}
 *		The created <code>Notification</code>
 */
ViewTestNote.create = function( body )	
		
{
	return new ViewTestNote().initialize( ViewTestNote.NAME, body );
}