/*
 PureMVC standard Javascript port by Frederic Saunier Saunier <frederic.saunier@puremvc.org>
 PureMVC - Copyright(c) 2006-2011 Futurescale, Inc., Some rights reserved.
 Your reuse is governed by the Creative Commons Attribution 3.0 License
*/

/**
 * Test the PureMVC Mediator class.
 * 
 * @see org.puremvc.js.standard.interfaces.IMediator IMediator
 * @see org.puremvc.js.standard.patterns.mediator.Mediator Mediator
 */
var MediatorTest = new YUITest.TestCase
(
	{
       /**
         * The name of the test case - if not provided, one is automatically
         * generated by the YUITest framework.
         * 
         * @type {String}
         * @private
         */
        name: "PureMVC Mediator class tests",  

        /**
         * Sets up data that is needed by each test.
         */
        setUp: function()
		{
        },
        
        /**
         * Cleans up everything that was created by setUp().
         */
        tearDown: function()
		{
        },

  		/**
  		 * Tests if constructing the Mediator also call its super by testing
  		 * for the existence of its <code>Notifier</code> superclass facade
  		 * instance.
  		 */
  		testConstructor: function()
		{
			// Create a new subclass of Notifier and verify that its facade
			// has well been created
   			var mediatorTestSub/*MediatorTestSub*/ = new MediatorTestSub().initialize();     

   			// test assertions
   			YUITest.Assert.isTrue
			(
				mediatorTestSub.hasFacade(),
				"Expecting mediatorTestSub.hasFacade() === true"
			);
   		},

		/**
  		 * Tests getting the name using Mediator class accessor method.
  		 */
  		testNameAccessor: function()
		{
			// Create a new Mediator and use accessors to set the mediator name 
   			var mediator/*Mediator*/ = new Mediator().initialize();
   			
   			// test assertions
   			YUITest.Assert.areEqual
			(
				Mediator.NAME,
				mediator.getMediatorName(),
				"Expecting mediator.getMediatorName() == Mediator.NAME"
			);
   		},

  		/**
  		 * Tests getting the name using Mediator class accessor method. 
  		 */
  		testViewAccessor: function()
		{
			// Create a view object
			var view/*Object*/ = new Object();
			
			// Create a new Proxy and use accessors to set the proxy name 
   			var mediator/*Mediator*/ = new Mediator().initialize( Mediator.NAME, view );
			   			
   			// test assertions
   			YUITest.Assert.isNotNull
			(
				mediator.getViewComponent(),
				"Expecting mediator.getViewComponent() !== null"
			);
   		}

  	}
);